@@ -1,4 +1,3 @@
-use crate::AuthSessionLayer;
 use anyhow::Error;
 use async_trait::async_trait;
 use axum_core::extract::{FromRequest, RequestParts};
@@ -8,13 +7,20 @@ use http::{self, StatusCode};
 ///This is the AuthSession that is generated when a user is routed to a page that Needs one
 /// It is used to load the user from there SqlxSession stored ID.
 #[derive(Debug, Clone)]
-pub struct AuthSession<D> {
+pub struct AuthSession<D>
+where
+    D: Authentication<D> + Send,
+{
+    pub id: u64,
     pub current_user: Option<D>,
-    pub(crate) session: AxumSession,
+    pub session: AxumSession,
 }
 
 #[async_trait]
-pub trait Authentication<D> {
+pub trait Authentication<D>
+where
+    D: Send,
+{
     async fn load_user(userid: i64, pool: Option<&AxumDatabasePool>) -> Result<D, Error>;
     fn is_authenticated(&self) -> bool;
     fn is_active(&self) -> bool;
@@ -28,53 +34,24 @@ pub trait Authentication<D> {
 impl<B, D> FromRequest<B> for AuthSession<D>
 where
     B: Send,
-    D: Authentication<D>,
+    D: Authentication<D> + Clone + Send + Sync + 'static,
 {
     type Rejection = (http::StatusCode, &'static str);
-
     async fn from_request(req: &mut RequestParts<B>) -> Result<Self, Self::Rejection> {
         let extensions = req.extensions().ok_or((
             StatusCode::INTERNAL_SERVER_ERROR,
-            "Can't extract SQLxSession: extensions has been taken by another extractor",
+            "Can't extract AuthSession: extensions has been taken by another extractor",
         ))?;
-        let session = extensions.get::<AxumSession>().cloned().ok_or((
+        extensions.get::<AuthSession<D>>().cloned().ok_or((
             StatusCode::INTERNAL_SERVER_ERROR,
-            "Can't extract SQLxSession. Is `SQLxSessionLayer` enabled?",
-        ))?;
-        let authlayer = extensions.get::<AuthSessionLayer>().cloned().ok_or((
-            StatusCode::INTERNAL_SERVER_ERROR,
-            "Can't extract AuthSessionLayer. Is `AuthSessionLayer` enabled?",
-        ))?;
-
-        let current_id = if let Some(id) = session.get::<i64>("user_auth_session_id").await {
-            Some(id)
-        } else {
-            authlayer.anonymous_user_id
-        };
-
-        let current_user = {
-            match current_id {
-                None => None,
-                Some(uid) => {
-                    if let Some(poll) = &authlayer.poll {
-                        D::load_user(uid, Some(poll)).await.ok()
-                    } else {
-                        D::load_user(uid, None).await.ok()
-                    }
-                }
-            }
-        };
-
-        Ok(AuthSession {
-            current_user,
-            session,
-        })
+            "Can't extract AuthSession. Is `AuthSessionLayer` enabled?",
+        ))
     }
 }
 
 impl<D> AuthSession<D>
 where
-    D: Authentication<D>,
+    D: Authentication<D> + Clone + Send,
 {
     /// Use this to check if the user is Authenticated
     pub fn is_authenticated(&self) -> bool {
